@@ -1,11 +1,12 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "calfw-org" "20251023.2205"
+(define-package "calfw-org" "20251030.845"
   "Calendar view for org-agenda."
   '((emacs "28.1")
-    (calfw "2.0"))
+    (calfw "2.0")
+    (org   "9.7"))
   :url "https://github.com/haji-ali/emacs-calfw"
-  :commit "de895bc8071b26209c6f9b9a665004d9bc6456f8"
-  :revdesc "de895bc8071b"
+  :commit "57be107b20625c13ed010cb0f70a603a61d47629"
+  :revdesc "57be107b2062"
   :keywords '("calendar" "org")
   :authors '(("SAKURAI Masashi" . "m.sakuraiatkiwanami.net"))
   :maintainers '(("Al Haji-Ali" . "abdo.haji.aliatgmail.com")))
