@@ -4,10 +4,10 @@
 
 ;; Author: SAKURAI Masashi <m.sakurai at kiwanami.net>
 ;; Maintainer: Al Haji-Ali <abdo.haji.ali at gmail.com>
-;; Package-Version: 20251023.2205
-;; Package-Revision: de895bc8071b
+;; Package-Version: 20251030.845
+;; Package-Revision: 57be107b2062
 ;; Keywords: calendar, org
-;; Package-Requires: ((emacs "28.1") (calfw "2.0"))
+;; Package-Requires: ((emacs "28.1") (calfw "2.0") (org "9.7"))
 ;; URL: https://github.com/haji-ali/emacs-calfw
 
 ;; This program is free software; you can redistribute it and/or modify
@@ -89,17 +89,13 @@ v w | `calfw-change-view-week'
 v m | `calfw-change-view-month'
 ------------------------------------------------")
 
-(defvar calfw-org-face-agenda-item-foreground-color "Seagreen4"
-  "Variable for org agenda item foreground color.")
-
 (defun calfw-org--collect-schedules-period (org-files begin end)
   "Return org schedule items between BEGIN and END from ORG-FILES."
   (let ((org-agenda-prefix-format " "))
-    ;; @AL: This seems wrong
-    ;; (setq org-agenda-buffer
-    ;;       (when (buffer-live-p org-agenda-buffer)
-    ;;         org-agenda-buffer))
-    (org-compile-prefix-format nil)
+    (let ((org-agenda-buffer
+           (when (buffer-live-p org-agenda-buffer)
+             org-agenda-buffer)))
+      (org-compile-prefix-format nil))
 
     ;; We need several hacks to resolve issues like those in #91.
     ;;
@@ -129,7 +125,7 @@ v m | `calfw-change-view-month'
           ;; existing `date' property for schedules and
           ;; deadlines.
           (mapcar (lambda (entry) (calfw--tp entry 'date date))
-                  (apply 'org-agenda-get-day-entries
+                  (apply #'org-agenda-get-day-entries
                          file date
                          calfw-org-agenda-schedule-args))))))))
 
@@ -149,7 +145,7 @@ v m | `calfw-change-view-month'
       (switch-to-buffer (marker-buffer marker))
       (widen)
       (goto-char (marker-position marker))
-      (when (eq major-mode 'org-mode)
+      (when (derived-mode-p 'org-mode)
         (org-reveal)))
     (when beg
       (find-file file)
@@ -186,7 +182,7 @@ v m | `calfw-change-view-month'
     ;; (when (string-match calfw-org-todo-keywords-regexp item) ; dynamic bind
     ;;   (setq item (replace-match "" nil nil item)))
     (if tags
-        (when (string-match (concat "[\t ]*:+" (mapconcat 'identity tags ":+") ":+[\t ]*$") item)
+        (when (string-match (concat "[\t ]*:+" (mapconcat #'identity tags ":+") ":+[\t ]*$") item)
           (setq item (replace-match "" nil nil item))))
     (when (string-match "[0-9]\\{2\\}:[0-9]\\{2\\}\\(-[0-9]\\{2\\}:[0-9]\\{2\\}\\)?[\t ]+" item)
       (setq item (replace-match "" nil nil item)))
@@ -217,7 +213,7 @@ ITEM is an org entry.  Return a string with text properties."
                                                  (org-agenda-deadline-face 1.0))
                            text))
     (if org-todo-keywords-for-agenda
-        (when (string-match (concat "^[\t ]*\\<\\(" (mapconcat 'identity org-todo-keywords-for-agenda "\\|") "\\)\\>") text)
+        (when (string-match (concat "^[\t ]*\\<\\(" (mapconcat #'identity org-todo-keywords-for-agenda "\\|") "\\)\\>") text)
           (add-text-properties (match-beginning 1) (match-end 1) (list 'face (org-get-todo-face (match-string 1 text))) text)))
     ;;; ------------------------------------------------------------------------
     ;;; act for org link
@@ -234,20 +230,17 @@ ITEM is an org entry.  Return a string with text properties."
                             'org-link link)))
           (if desc
               (progn
-                (setq desc (apply 'propertize desc link-props))
+                (setq desc (apply #'propertize desc link-props))
                 (setq text (replace-match desc nil nil text)))
-            (setq link (apply 'propertize link link-props))
+            (setq link (apply #'propertize link link-props))
             (setq text (replace-match link nil nil text)))))
     (when time-str
       (setq text (concat time-str text)))
     (propertize
-     (apply 'propertize text props)
+     (apply #'propertize text props)
      ;; include org filename
      ;; (and buffer (concat " " (buffer-name buffer)))
-     'keymap calfw-org-text-keymap
-     ;; Delete the display property, since displaying images will break our
-     ;; table layout.
-     'display nil)))
+     'keymap calfw-org-text-keymap)))
 
 (defvar calfw-org-schedule-summary-transformer 'calfw-org-summary-format
   "Transforms the org item string to calendar title.
@@ -353,7 +346,6 @@ and `cfw:org-loc' properties."
               (org-element-property :minute-start t-obj)))
     (org-element-property :title h-obj))
    'keymap calfw-org-text-keymap
-   'display nil
    'cfw:org-file file
    'cfw:org-h-beg h-beg
    'cfw:org-loc loc))
@@ -465,7 +457,7 @@ Returns an alist of `:periods' and `:contents'."
   (with-current-buffer  (get-buffer-create calfw-calendar-buffer-name)
     (let ((pos (calfw-cursor-to-nearest-date)))
       (concat "<"
-              (format-time-string  "%Y-%m-%d %a"
+              (format-time-string  "%F %a"
                                    (encode-time 0 0 0
                                                 (calendar-extract-day pos)
                                                 (calendar-extract-month pos)
@@ -497,6 +489,7 @@ Open the `org-agenda' buffer for the date at point, DATE."
     (when date
       (org-agenda-list nil (calendar-absolute-from-gregorian date) 'day))))
 
+;; TODO: Need to find a better place to do org-specific mapping
 (define-key
  calfw-calendar-mode-map "c" 'calfw-org-capture)
 
@@ -520,36 +513,47 @@ Open the `org-agenda' buffer for the date at point, DATE."
      ("SPC" . calfw-org-open-agenda-day)))
   "Key map for the calendar buffer.")
 
-(defun calfw-org-create-source (name org-files color)
-  "Create a calfw source named NAME with org files ORG-FILES and COLOR."
+(defun calfw-org-create-source (org-files name color)
+  "Create a calfw source from a list of ORG-FILES with NAME and COLOR.
+ORG-FILES defaults to `org-agenda-files`."
   (make-calfw-source
    :name name :color color
-   :data (apply-partially 'calfw-org--schedule-period-to-calendar org-files)))
+   :data (apply-partially
+          #'calfw-org--schedule-period-to-calendar
+          (or org-files
+              (org-agenda-files nil 'ifmode)))))
 
-(cl-defun calfw-org-open-calendar (&optional name org-files)
+(cl-defun calfw-org-open-calendar
+    (&optional org-files
+               (name "org-agenda")
+               (color "Seagreen4")
+               &rest args
+               &key
+               (view 'month)
+               (sorter 'calfw-org--schedule-sorter)
+               (custom-map (if calfw-org-overwrite-default-keybinding
+                               calfw-org-custom-map
+                             calfw-org-schedule-map))
+               &allow-other-keys)
   "Open an org schedule calendar in a new buffer.
 
-Events are taken from ORG-FILES (defaults to those returned by
-`org-agenda-files') and NAME is the name of the calendar
-(defaults to \"org-agenda\")."
+Events are taken from ORG-FILES (defaults to `org-agenda-files`)
+and NAME is the name of the calendar (defaults to
+\"org-agenda\"). COLOR specifies the color of the calendar. Other
+keyword arguments such as VIEW, SORTER, and CUSTOM-MAP (with
+default values) along with ARGS are passed to
+`calfw-open-calendar-buffer'."
   (interactive)
-  (save-excursion
-    (let* ((source1 (calfw-org-create-source
-                     (or name "org-agenda")
-                     (or org-files
-                         (org-agenda-files nil 'ifmode))
-                     calfw-org-face-agenda-item-foreground-color))
-           (curr-keymap (if calfw-org-overwrite-default-keybinding
-                            calfw-org-custom-map
-                          calfw-org-schedule-map))
-           (cp (calfw-create-calendar-component-buffer
-                :view 'month
-                :contents-sources (list source1)
-                :custom-map curr-keymap
-                :sorter 'calfw-org--schedule-sorter)))
-      (switch-to-buffer (calfw-cp-get-buffer cp))
-      (when (not org-todo-keywords-for-agenda)
-        (message "Warn : open org-agenda buffer first.")))))
+  (apply #'calfw-open-calendar-buffer
+         :contents-sources
+         (list (calfw-org-create-source org-files name color))
+         :view view
+         :custom-map custom-map
+         :sorter sorter
+         args)
+
+  (when (not org-todo-keywords-for-agenda)
+    (message "Warning: open org-agenda buffer first.")))
 
 ;; (defun calfw-org-from-calendar ()
 ;;   "Do something. This command should be executed on the calfw calendar."
